[−][src]Enum unicode_types::oriya::Oriya
An enum to represent all characters in the Oriya block.
Variants
SignCandrabindu\u{b01}: 'ଁ'
SignAnusvara\u{b02}: 'ଂ'
SignVisarga\u{b03}: 'ଃ'
LetterA\u{b05}: 'ଅ'
LetterAa\u{b06}: 'ଆ'
LetterI\u{b07}: 'ଇ'
LetterIi\u{b08}: 'ଈ'
LetterU\u{b09}: 'ଉ'
LetterUu\u{b0a}: 'ଊ'
LetterVocalicR\u{b0b}: 'ଋ'
LetterVocalicL\u{b0c}: 'ଌ'
LetterE\u{b0f}: 'ଏ'
LetterAi\u{b10}: 'ଐ'
LetterO\u{b13}: 'ଓ'
LetterAu\u{b14}: 'ଔ'
LetterKa\u{b15}: 'କ'
LetterKha\u{b16}: 'ଖ'
LetterGa\u{b17}: 'ଗ'
LetterGha\u{b18}: 'ଘ'
LetterNga\u{b19}: 'ଙ'
LetterCa\u{b1a}: 'ଚ'
LetterCha\u{b1b}: 'ଛ'
LetterJa\u{b1c}: 'ଜ'
LetterJha\u{b1d}: 'ଝ'
LetterNya\u{b1e}: 'ଞ'
LetterTta\u{b1f}: 'ଟ'
LetterTtha\u{b20}: 'ଠ'
LetterDda\u{b21}: 'ଡ'
LetterDdha\u{b22}: 'ଢ'
LetterNna\u{b23}: 'ଣ'
LetterTa\u{b24}: 'ତ'
LetterTha\u{b25}: 'ଥ'
LetterDa\u{b26}: 'ଦ'
LetterDha\u{b27}: 'ଧ'
LetterNa\u{b28}: 'ନ'
LetterPa\u{b2a}: 'ପ'
LetterPha\u{b2b}: 'ଫ'
LetterBa\u{b2c}: 'ବ'
LetterBha\u{b2d}: 'ଭ'
LetterMa\u{b2e}: 'ମ'
LetterYa\u{b2f}: 'ଯ'
LetterRa\u{b30}: 'ର'
LetterLa\u{b32}: 'ଲ'
LetterLla\u{b33}: 'ଳ'
LetterVa\u{b35}: 'ଵ'
LetterSha\u{b36}: 'ଶ'
LetterSsa\u{b37}: 'ଷ'
LetterSa\u{b38}: 'ସ'
LetterHa\u{b39}: 'ହ'
SignNukta\u{b3c}: '଼'
SignAvagraha\u{b3d}: 'ଽ'
VowelSignAa\u{b3e}: 'ା'
VowelSignI\u{b3f}: 'ି'
VowelSignIi\u{b40}: 'ୀ'
VowelSignU\u{b41}: 'ୁ'
VowelSignUu\u{b42}: 'ୂ'
VowelSignVocalicR\u{b43}: 'ୃ'
VowelSignVocalicRr\u{b44}: 'ୄ'
VowelSignE\u{b47}: 'େ'
VowelSignAi\u{b48}: 'ୈ'
VowelSignO\u{b4b}: 'ୋ'
VowelSignAu\u{b4c}: 'ୌ'
SignVirama\u{b4d}: '୍'
AiLengthMark\u{b56}: 'ୖ'
AuLengthMark\u{b57}: 'ୗ'
LetterRra\u{b5c}: 'ଡ଼'
LetterRha\u{b5d}: 'ଢ଼'
LetterYya\u{b5f}: 'ୟ'
LetterVocalicRr\u{b60}: 'ୠ'
LetterVocalicLl\u{b61}: 'ୡ'
VowelSignVocalicL\u{b62}: 'ୢ'
VowelSignVocalicLl\u{b63}: 'ୣ'
DigitZero\u{b66}: '୦'
DigitOne\u{b67}: '୧'
DigitTwo\u{b68}: '୨'
DigitThree\u{b69}: '୩'
DigitFour\u{b6a}: '୪'
DigitFive\u{b6b}: '୫'
DigitSix\u{b6c}: '୬'
DigitSeven\u{b6d}: '୭'
DigitEight\u{b6e}: '୮'
DigitNine\u{b6f}: '୯'
Isshar\u{b70}: '୰'
LetterWa\u{b71}: 'ୱ'
FractionOneQuarter\u{b72}: '୲'
FractionOneHalf\u{b73}: '୳'
FractionThreeQuarters\u{b74}: '୴'
FractionOneSixteenth\u{b75}: '୵'
FractionOneEighth\u{b76}: '୶'
FractionThreeSixteenths\u{b77}: '୷'
Methods
impl Oriya[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case